summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/attribute.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/attribute.cpp')
-rw-r--r--umbrello/umbrello/attribute.cpp30
1 files changed, 15 insertions, 15 deletions
diff --git a/umbrello/umbrello/attribute.cpp b/umbrello/umbrello/attribute.cpp
index d18f4d5e..9266c1f4 100644
--- a/umbrello/umbrello/attribute.cpp
+++ b/umbrello/umbrello/attribute.cpp
@@ -23,11 +23,11 @@
#include "dialogs/umlattributedialog.h"
#include "object_factory.h"
-UMLAttribute::UMLAttribute( const UMLObject *tqparent,
+UMLAttribute::UMLAttribute( const UMLObject *parent,
const TQString& name, Uml::IDType id,
Uml::Visibility s,
UMLObject *type, const TQString& iv )
- : UMLClassifierListItem(tqparent, name, id) {
+ : UMLClassifierListItem(parent, name, id) {
m_InitialValue = iv;
m_BaseType = Uml::ot_Attribute;
m_Vis = s;
@@ -40,7 +40,7 @@ UMLAttribute::UMLAttribute( const UMLObject *tqparent,
m_pSecondary = type;
}
-UMLAttribute::UMLAttribute(const UMLObject *tqparent) : UMLClassifierListItem(tqparent) {
+UMLAttribute::UMLAttribute(const UMLObject *parent) : UMLClassifierListItem(parent) {
m_BaseType = Uml::ot_Attribute;
m_Vis = Uml::Visibility::Private;
m_ParmKind = Uml::pd_In;
@@ -88,15 +88,15 @@ TQString UMLAttribute::toString(Uml::Signature_Type sig) {
if(sig == Uml::st_ShowSig || sig == Uml::st_SigNoVis) {
// Determine whether the type name needs to be scoped.
- UMLObject *owningObject = static_cast<UMLObject*>(tqparent());
+ UMLObject *owningObject = static_cast<UMLObject*>(parent());
if (owningObject->getBaseType() == Uml::ot_Operation) {
// The immediate tqparent() is the UMLOperation but we want
// the UMLClassifier:
- owningObject = static_cast<UMLObject*>(owningObject->tqparent());
+ owningObject = static_cast<UMLObject*>(owningObject->parent());
}
UMLClassifier *ownParent = dynamic_cast<UMLClassifier*>(owningObject);
if (ownParent == NULL) {
- kError() << "UMLAttribute::toString: tqparent "
+ kError() << "UMLAttribute::toString: parent "
<< owningObject->getName()
<< " is not a UMLClassifier" << endl;
return "";
@@ -129,15 +129,15 @@ TQString UMLAttribute::toString(Uml::Signature_Type sig) {
TQString UMLAttribute::getFullyQualifiedName( const TQString& separator,
bool includeRoot /* = false */) const {
UMLOperation *op = NULL;
- UMLObject *owningObject = static_cast<UMLObject*>(tqparent());
+ UMLObject *owningObject = static_cast<UMLObject*>(parent());
if (owningObject->getBaseType() == Uml::ot_Operation) {
op = static_cast<UMLOperation*>(owningObject);
- owningObject = static_cast<UMLObject*>(owningObject->tqparent());
+ owningObject = static_cast<UMLObject*>(owningObject->parent());
}
UMLClassifier *ownParent = dynamic_cast<UMLClassifier*>(owningObject);
if (ownParent == NULL) {
kError() << "UMLAttribute::getFullyQualifiedName(" << m_Name
- << "): tqparent " << owningObject->getName()
+ << "): parent " << owningObject->getName()
<< " is not a UMLClassifier" << endl;
return "";
}
@@ -168,7 +168,7 @@ bool UMLAttribute::operator==( UMLAttribute &rhs) {
void UMLAttribute::copyInto(UMLAttribute *rhs) const
{
// call the tqparent first.
UMLClassifierListItem::copyInto(rhs);
// Copy all datamembers
@@ -180,8 +180,8 @@ void UMLAttribute::copyInto(UMLAttribute *rhs) const
UMLObject* UMLAttribute::clone() const
{
- //FIXME: The new attribute should be slaved to the NEW tqparent not the old.
- UMLAttribute *clone = new UMLAttribute( static_cast<UMLObject*>(tqparent()) );
+ //FIXME: The new attribute should be slaved to the NEW parent not the old.
+ UMLAttribute *clone = new UMLAttribute( static_cast<UMLObject*>(parent()) );
copyInto(clone);
return clone;
@@ -249,8 +249,8 @@ bool UMLAttribute::load( TQDomElement & element ) {
return true;
}
-bool UMLAttribute::showPropertiesDialog(TQWidget* tqparent) {
- UMLAttributeDialog dialog(tqparent, this);
+bool UMLAttribute::showPropertiesDialog(TQWidget* parent) {
+ UMLAttributeDialog dialog(parent, this);
return dialog.exec();
}
@@ -88,15 +88,15 @@ TQString UMLAttribute::toString(Uml::Signature_Type sig) {
if (owningObject->getBaseType() == Uml::ot_Operation) {
- // The immediate tqparent() is the UMLOperation but we want
+ // The immediate parent() is the UMLOperation but we want
// the UMLClassifier:
@@ -168,7 +168,7 @@ bool UMLAttribute::operator==( UMLAttribute &rhs) {
void UMLAttribute::copyInto(UMLAttribute *rhs) const
{
- // call the tqparent first.
+ // call the parent first.
UMLClassifierListItem::copyInto(rhs);
// Copy all datamembers